seq/rest_n.hpp

The seq/rest_n.hpp header defines a macro for extracting a group of elements from the end of a seq.

#### Usage

#include <boost/preprocessor/seq/rest_n.hpp>

#### Contents

- BOOST_PP_SEQ_REST_N

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)